<?php
/**
* Breaking News Section options
*
* @package Theme Palace
* @subpackage Magazine Palace
* @since Magazine Palace 1.0.0
*/

// Add Breaking News section
$wp_customize->add_section( 'magazine_palace_breakingnews_section', array(
	'title'             => esc_html__( 'Breaking News','magazine-palace' ),
	'description'       => esc_html__( 'Breaking News Section options.', 'magazine-palace' ),
	'panel'             => 'magazine_palace_front_page_panel',
	'priority'          => 3, 
	) );

// Breaking News content enable control and setting
$wp_customize->add_setting( 'magazine_palace_theme_options[breakingnews_section_enable]', array(
	'default'			=> 	$options['breakingnews_section_enable'],
	'sanitize_callback' => 'magazine_palace_sanitize_switch_control',
	) );

$wp_customize->add_control( new Magazine_palace_Switch_Control( $wp_customize, 'magazine_palace_theme_options[breakingnews_section_enable]', array(
	'label'             => esc_html__( 'Breaking News Section Enable', 'magazine-palace' ),
	'section'           => 'magazine_palace_breakingnews_section',
	'on_off_label' 		=> magazine_palace_switch_options(),
	) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'magazine_palace_theme_options[breakingnews_section_enable]',
		array(
			'selector'            => '#magazine_palace_breakingnews_section .tooltiptext',
			'settings'            => 'magazine_palace_theme_options[breakingnews_section_enable]',
		)
	);
}

$wp_customize->add_setting( 
    'magazine_palace_theme_options_breakingnews_setting_style',
    array(
        'sanitize_callback' => 'sanitize_text_field',
    )
);

$wp_customize->add_control( 
    new Magazine_palace_Customize_Control_Section_Style( 
    $wp_customize,
    'magazine_palace_theme_options_breakingnews_setting_style',
        array(
            'section'       => 'magazine_palace_breakingnews_section',
            'active_callback' 	=> 'magazine_palace_is_breakingnews_section_enable',
            'choices'  => array(

                'setting'    => array(
                    'name' => esc_html__( 'Setting', 'magazine-palace' ),
                    'section_id' => 'magazine_palace_breakingnews_section',
                ),
                
                'style'    => array(
                    'name' => esc_html__( 'Style', 'magazine-palace' ),
                    'section_id' => 'magazine_palace_breakingnews_section_style',
                ),
            ),
        )
    )
);

$wp_customize->add_setting( 'magazine_palace_theme_options[breakingnews_featured_image_enable]', array(
	'default'			=> 	$options['breakingnews_featured_image_enable'],
	'sanitize_callback' => 'magazine_palace_sanitize_switch_control',
) );

$wp_customize->add_control( new Magazine_palace_Switch_Control( $wp_customize, 'magazine_palace_theme_options[breakingnews_featured_image_enable]', array(
	'label'             => esc_html__( 'Breaking Featured Image Enable', 'magazine-palace' ),
	'section'           => 'magazine_palace_breakingnews_section',
	'active_callback' 	=> 'magazine_palace_is_breakingnews_section_enable',
	'on_off_label' 		=> magazine_palace_switch_options(),
) ) );


// breakingnews title setting and control
$wp_customize->add_setting( 'magazine_palace_theme_options[breakingnews_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['breakingnews_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'magazine_palace_theme_options[breakingnews_title]', array(
	'label'           	=> esc_html__( 'Title', 'magazine-palace' ),
	'section'        	=> 'magazine_palace_breakingnews_section',
	'active_callback' 	=> 'magazine_palace_is_breakingnews_section_enable',
	'type'				=> 'text',
	) );

$wp_customize->add_setting( 'magazine_palace_theme_options[breaking_news_icon]', array(
	'default'           => $options['breaking_news_icon'],
	'sanitize_callback' => 'magazine_palace_sanitize_select',
) );

$wp_customize->add_control( 'magazine_palace_theme_options[breaking_news_icon]', array(
	'type'    => 'radio',
	'label'    => esc_html__( 'Breaking News Icon Type', 'magazine-palace' ),
	'choices'  => array(
        'wave'   => esc_html__( 'Bubble Wave Effect', 'magazine-palace' ),
        'speaker'   => esc_html__( 'Speaker Icon', 'magazine-palace' ),
	),
	'section'  => 'magazine_palace_breakingnews_section',
) );

for ( $i = 1; $i <= 5; $i++ ) :

// breakingnews posts drop down chooser control and setting
$wp_customize->add_setting( 'magazine_palace_theme_options[breakingnews_content_post_' . $i . ']', array(
	'sanitize_callback' => 'magazine_palace_sanitize_page',
	) );

$wp_customize->add_control( new Magazine_palace_Dropdown_Chooser( $wp_customize, 'magazine_palace_theme_options[breakingnews_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'magazine-palace' ), $i ),
	'section'           => 'magazine_palace_breakingnews_section',
	'choices'			=> magazine_palace_post_choices(),
	'active_callback'	=> 'magazine_palace_is_breakingnews_section_enable',
	) ) );

endfor;
