<?php
/**
* Three Col Slider Section options
*
* @package Theme Palace
* @subpackage Magazine Palace
* @since Magazine Palace 1.0.0
*/

// Add Three Col Slider section
$wp_customize->add_section( 'magazine_palace_three_col_slider_section', array(
	'title'             => esc_html__( 'Three Col Slider','magazine-palace' ),
	'description'       => esc_html__( 'Three Col Slider Section options.', 'magazine-palace' ),
	'panel'             => 'magazine_palace_front_page_panel',
	) );

// Three Col Slider content enable control and setting
$wp_customize->add_setting( 'magazine_palace_theme_options[three_col_slider_section_enable]', array(
	'default'			=> 	$options['three_col_slider_section_enable'],
	'sanitize_callback' => 'magazine_palace_sanitize_switch_control',
	) );

$wp_customize->add_control( new Magazine_palace_Switch_Control( $wp_customize, 'magazine_palace_theme_options[three_col_slider_section_enable]', array(
	'label'             => esc_html__( 'Three Col Slider Section Enable', 'magazine-palace' ),
	'section'           => 'magazine_palace_three_col_slider_section',
	'on_off_label' 		=> magazine_palace_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'magazine_palace_theme_options[three_col_slider_section_enable]',
        array(
            'selector'            => '#magazine_palace_three_col_slider_section .tooltiptext',
            'settings'            => 'magazine_palace_theme_options[three_col_slider_section_enable]',
        )
    );
}

$wp_customize->add_setting( 
    'magazine_palace_theme_options_three_col_slider_setting_style',
    array(
        'sanitize_callback' => 'sanitize_text_field',
    )
);

$wp_customize->add_control( 
    new Magazine_palace_Customize_Control_Section_Style( 
    $wp_customize,
    'magazine_palace_theme_options_three_col_slider_setting_style',
        array(
            'section'       => 'magazine_palace_three_col_slider_section',
            'active_callback' 	=> 'magazine_palace_is_three_col_slider_section_enable',
            'choices'  => array(

                'setting'    => array(
                    'name' => esc_html__( 'Setting', 'magazine-palace' ),
                    'section_id' => 'magazine_palace_three_col_slider_section',
                ),
                
                'style'    => array(
                    'name' => esc_html__( 'Style', 'magazine-palace' ),
                    'section_id' => 'magazine_palace_three_col_slider_section_style',
                ),
            ),
        )
    )
);

$wp_customize->add_setting( 'magazine_palace_theme_options[three_col_slider_autoplay_enable]', array(
	'default'			=> 	$options['three_col_slider_autoplay_enable'],
	'sanitize_callback' => 'magazine_palace_sanitize_switch_control',
	) );

$wp_customize->add_control( new Magazine_palace_Switch_Control( $wp_customize, 'magazine_palace_theme_options[three_col_slider_autoplay_enable]', array(
	'label'             => esc_html__( 'Slider Autoplay Enable', 'magazine-palace' ),
	'section'           => 'magazine_palace_three_col_slider_section',
	'active_callback' 	=> 'magazine_palace_is_three_col_slider_section_enable',
	'on_off_label' 		=> magazine_palace_switch_options(),
) ) );


// three_col_slider title setting and control
$wp_customize->add_setting( 'magazine_palace_theme_options[three_col_slider_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['three_col_slider_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'magazine_palace_theme_options[three_col_slider_title]', array(
	'label'           	=> esc_html__( 'Title', 'magazine-palace' ),
	'section'        	=> 'magazine_palace_three_col_slider_section',
	'active_callback' 	=> 'magazine_palace_is_three_col_slider_section_enable',
	'type'				=> 'text',
	) );


for ( $i = 1; $i <= 5; $i++ ) :


// three_col_slider posts drop down chooser control and setting
$wp_customize->add_setting( 'magazine_palace_theme_options[three_col_slider_content_post_' . $i . ']', array(
	'sanitize_callback' => 'magazine_palace_sanitize_page',
) );

$wp_customize->add_control( new Magazine_palace_Dropdown_Chooser( $wp_customize, 'magazine_palace_theme_options[three_col_slider_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'magazine-palace' ), $i ),
	'section'           => 'magazine_palace_three_col_slider_section',
	'choices'			=> magazine_palace_post_choices(),
	'active_callback'	=> 'magazine_palace_is_three_col_slider_section_enable',
) ) );
endfor;
