<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Magazine Palace
 * @since Magazine Palace 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function magazine_palace_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'magazine-palace' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function magazine_palace_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'magazine-palace' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function magazine_palace_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'magazine-palace' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}



if ( ! function_exists( 'magazine_palace_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function magazine_palace_site_layout() {
        $magazine_palace_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'magazine_palace_site_layout', $magazine_palace_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'magazine_palace_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function magazine_palace_selected_sidebar() {
        $magazine_palace_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'magazine-palace' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'magazine-palace' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'magazine-palace' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'magazine-palace' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'magazine-palace' ),
        );

        $output = apply_filters( 'magazine_palace_selected_sidebar', $magazine_palace_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'magazine_palace_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function magazine_palace_global_sidebar_position() {
        $magazine_palace_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'magazine_palace_global_sidebar_position', $magazine_palace_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'magazine_palace_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function magazine_palace_sidebar_position() {
        $magazine_palace_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'magazine_palace_sidebar_position', $magazine_palace_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'magazine_palace_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function magazine_palace_pagination_options() {
        $magazine_palace_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'magazine-palace' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'magazine-palace' ),
        );

        $output = apply_filters( 'magazine_palace_pagination_options', $magazine_palace_pagination_options );

        return $output;
    }
endif;


if ( ! function_exists( 'magazine_palace_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function magazine_palace_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'magazine-palace' ),
            'off'       => esc_html__( 'Disable', 'magazine-palace' )
        );
        return apply_filters( 'magazine_palace_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'magazine_palace_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function magazine_palace_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'magazine-palace' ),
            'off'       => esc_html__( 'No', 'magazine-palace' )
        );
        return apply_filters( 'magazine_palace_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'magazine_palace_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function magazine_palace_sortable_sections() {
        $sections = array(
            'breakingnews'  => esc_html__( 'Breaking News', 'magazine-palace' ),
            'slider_news'    => esc_html__( 'Slider News', 'magazine-palace' ),
            'have_missed'    => esc_html__( 'Have Missed', 'magazine-palace' ),
            'featured_post'    => esc_html__( 'Featured Post', 'magazine-palace' ),
            'main_content'    => esc_html__( 'Main Content', 'magazine-palace' ),
          );
        return apply_filters( 'magazine_palace_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'magazine_palace_inner_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function magazine_palace_inner_sortable_sections() {
        $sections = array(
            'banner_post'  => esc_html__( 'Banner Post', 'magazine-palace' ),
            'three_col_slider'    => esc_html__( 'Three Col Slider', 'magazine-palace' ),
            'two_col'    => esc_html__( 'Two Col', 'magazine-palace' ),
          );
        return apply_filters( 'magazine_palace_inner_sortable_sections', $sections );
    }
endif;

function magazine_palace_get_post_cat_choices() {
  $choices = array( '' => esc_html__( '--Select--', 'magazine-palace' ) );
    $cats = get_categories();
    foreach ( $cats as $cat ) {
        $id = $cat->term_id;
        $title = $cat->name;
        $choices[ $id ] = $title;
    }
    return $choices;
}