<?php
/**
 * Headline section
 *
 * This is the template for the content of breakingnews section
 *
 * @package Theme Palace
 * @subpackage Magazine Palace
 * @since Magazine Palace 1.0.0
 */
if ( ! function_exists( 'magazine_palace_add_breakingnews_section' ) ) :
    /**
    * Add breakingnews section
    *
    *@since Magazine Palace 1.0.0
    */
    function magazine_palace_add_breakingnews_section() {
    	$options = magazine_palace_get_theme_options();
        // Check if breakingnews is enabled on frontpage
        $breakingnews_enable = apply_filters( 'magazine_palace_section_status', true, 'breakingnews_section_enable' );

        if ( true !== $breakingnews_enable ) {
            return false;
        }
        // Get breakingnews section details
        $section_details = array();
        $section_details = apply_filters( 'magazine_palace_filter_breakingnews_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render breakingnews section now.
        magazine_palace_render_breakingnews_section( $section_details );
    }
endif;

if ( ! function_exists( 'magazine_palace_get_breakingnews_section_details' ) ) :
    /**
    * breakingnews section details.
    *
    * @since Magazine Palace 1.0.0
    * @param array $input breakingnews section details.
    */
    function magazine_palace_get_breakingnews_section_details( $input ) {
        $options = magazine_palace_get_theme_options();
        
        $content = array();

        $post_ids = array();

        for ( $i = 1; $i <= 5; $i++ ) {
            if ( ! empty( $options['breakingnews_content_post_' . $i] ) )
                $post_ids[] = $options['breakingnews_content_post_' . $i];
        }
        $args = array(
            'post_type'         => 'post',
            'post__in'          => ( array ) $post_ids,
            'posts_per_page'    => 5,
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
        );                    

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['title']     = get_the_title();
               $page_post['image']      = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                $page_post['url']       = get_the_permalink();

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// breakingnews section content details.
add_filter( 'magazine_palace_filter_breakingnews_section_details', 'magazine_palace_get_breakingnews_section_details' );


if ( ! function_exists( 'magazine_palace_render_breakingnews_section' ) ) :
  /**
   * Start breakingnews section
   *
   * @return string breakingnews content
   * @since Magazine Palace 1.0.0
   *
   */
function magazine_palace_render_breakingnews_section( $content_details = array() ) {
    $options = magazine_palace_get_theme_options();
    $title = ! empty( $options['breakingnews_title'] ) ? $options['breakingnews_title'] : esc_html__( 'Breaking News', 'magazine-palace' );

    if ( empty( $content_details ) ) {
        return;
    } ?>
    <div id="magazine_palace_breakingnews_section" class="relative home-section breaking-news">
        <div class="wrapper">
            <?php if ( is_customize_preview()):
                magazine_palace_section_tooltip( 'breaking-news-class' );
            endif; ?>
            <div class="breaking-news-post">
                <h2 class="news-title"><?php echo esc_html( $title ); ?></h2>
                <div class="bubble">
                    <?php if ($options['breaking_news_icon'] == 'speaker'): ?>
                        <svg version="1.1" id="Capa_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 560.979 560.979">

                            <path d="M373.795,91.455v172.339v172.34c0,12.539-16.436,17.558-23.201,7.004c-38.713-60.337-76.948-91.978-211.228-98.682
                                l42.391,137.802h-63.355L75.527,342.892C33.524,340.968,0,306.273,0,263.794C0,220.077,35.476,184.5,79.193,184.5
                                c184.144,0,227.432-31.525,271.395-100.056C357.359,73.897,373.795,78.916,373.795,91.455z M482.854,280.495
                                c0,33.027-11.111,63.362-27.832,86.312c0,0-6.697,9.173-17.816,9.173c-11.443,0-21.549-9.608-21.549-21.665
                                c0-7.119,4.264-12.906,4.264-12.906c7.957-11.635,19.611-29.505,19.611-60.914s-11.654-49.286-19.611-60.921
                                c0,0-4.264-5.787-4.264-12.906c0-12.057,10.105-21.665,21.549-21.665c11.119,0,17.816,9.173,17.816,9.173
                                C471.75,217.133,482.854,247.468,482.854,280.495z M466.771,155.471c0,0-9.777-6.991-9.777-17.945
                                c0-12.329,10.125-21.747,21.664-21.747c7.42,0,14.254,5.229,14.254,5.229c26.186,19.584,68.066,69.769,68.066,159.487
                                s-41.887,139.903-68.074,159.487c0,0-6.834,5.229-14.252,5.229c-11.533,0-21.666-9.418-21.666-21.746
                                c0-10.955,9.779-17.945,9.779-17.945c30.477-22.487,50.877-67.436,50.877-125.024S497.242,177.958,466.771,155.471z"/>

                        </svg>
                        <?php else: ?>
                            <div></div>
                            <div></div>
                            <div></div>
                            <div></div>
                            <div></div>
                    <?php endif ?>                    
                </div>
                <div class="marquee-content">
                    <ul class="marquee">
                        <?php foreach ( $content_details as $content ) : ?>
                            <li>
                                <div class="breaking-news-wrapper">
                                    <?php if ( $options['breakingnews_featured_image_enable'] ): ?>
                                        <div class="featured-image">
                                            <img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                                        </div>
                                    <?php endif ?>                                    
                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>
                                    </div><!-- .entry-container -->
                                </div>
                            </li>
                        <?php endforeach; ?>
                    </ul><!-- section-content -->
                </div>
            </div>
        </div>
    </div>
    
    <?php }
    endif;

