<?php
/**
* Post Carousel section
*
* This is the template for the content of have_missed section
*
* @package Theme Palace
* @subpackage Magazine Palace
* @since Magazine Palace 1.0.0
*/
if ( ! function_exists( 'magazine_palace_add_have_missed_section' ) ) :
/**
* Add have_missed section
*
*@since Magazine Palace 1.0.0
*/
function magazine_palace_add_have_missed_section() {
    $options = magazine_palace_get_theme_options();
    // Check if have_missed is enabled on frontpage
    $have_missed_enable = apply_filters( 'magazine_palace_section_status', true, 'have_missed_section_enable' );

    if ( true !== $have_missed_enable ) {
        return false;
    }
    // Get have_missed section details
    $section_details = array();
    $section_details = apply_filters( 'magazine_palace_filter_have_missed_section_details', $section_details );

    if ( empty( $section_details ) ) {
        return;
    }

// Render have_missed section now.
    magazine_palace_render_have_missed_section( $section_details );
}
endif;

if ( ! function_exists( 'magazine_palace_get_have_missed_section_details' ) ) :
/**
* have_missed section details.
*
* @since Magazine Palace 1.0.0
* @param array $input have_missed section details.
*/
function magazine_palace_get_have_missed_section_details( $input ) {
    $options = magazine_palace_get_theme_options();
    $content = array();

    $post_ids = array();

    for ( $i = 1; $i <= 4; $i++ ) {
        if ( ! empty( $options['have_missed_content_post_' . $i] ) )
            $post_ids[] = $options['have_missed_content_post_' . $i];
    }

    $args = array(
        'post_type'         => 'post',
        'post__in'          => ( array ) $post_ids,
        'posts_per_page'    => 4,
        'orderby'           => 'post__in',
        'ignore_sticky_posts'   => true,
        );                    
        

    // Run The Loop.
    $query = new WP_Query( $args );
    if ( $query->have_posts() ) : 
        while ( $query->have_posts() ) : $query->the_post();
    $page_post['id']        = get_the_id();
    $page_post['title']     = get_the_title();
    $page_post['auth_id']   = get_the_author_meta('ID');
    $page_post['url']       = get_the_permalink();
    $page_post['excerpt']   = get_the_content();
    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

// Push to the main array.
    array_push( $content, $page_post );
    endwhile;
    endif;
    wp_reset_postdata();

    if ( ! empty( $content ) ) {
        $input = $content;
    }
    return $input;
}
endif;
// have_missed section content details.
add_filter( 'magazine_palace_filter_have_missed_section_details', 'magazine_palace_get_have_missed_section_details' );


if ( ! function_exists( 'magazine_palace_render_have_missed_section' ) ) :
/**
* Start have_missed section
*
* @return string have_missed content
* @since Magazine Palace 1.0.0
*
*/
function magazine_palace_render_have_missed_section( $content_details = array() ) {
    $options = magazine_palace_get_theme_options();
  ?>
<div id="magazine_palace_have_missed_section" class="relative home-section have-missed">
    <div class="wrapper">
        <?php if ( is_customize_preview()):
            magazine_palace_section_tooltip( 'have-missed-class' );
        endif; ?>
        <?php if ( ! empty( $options['have_missed_title'] ) ) : ?>
            <div class="section-header">
                <h2 class="section-title"><?php echo esc_html( $options['have_missed_title'] ); ?></h2>
            </div><!-- .section-header -->
        <?php endif; ?>
        <div class="section-content col-4">
            <?php foreach ( $content_details as $content ) : ?>
                <article>
                    <div class="featured-wrapper">
                        <div class="featured-image">
                            <img src="<?php echo esc_url( $content['image'] ); ?>">
                        </div>
                        

                        <div class="entry-container">
                            <span class="cat-links">
                                <?php the_category( '', '', $content['id'] ); ?>
                            </span>
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>
                            <div class="entry-meta">
                                <?php magazine_palace_posted_on( $content['id'] ); ?>
                                <span class="min-read"><?php echo magazine_palace_time_interval($content['excerpt']); echo esc_html__(' min to read', 'magazine-palace'); ?></span>
                            </div>
                        </div>
                    </div>
                </article>
            <?php endforeach; ?>            
        </div>
    </div>
</div>
<?php }
    endif;