<?php
/**
* Slide secrtion
*
* This is the template for the content of slider_news section
*
* @package Theme Palace
* @subpackage Magazine Palace
* @since Magazine Palace 1.0.0
*/
if ( ! function_exists( 'magazine_palace_add_slider_news_section' ) ) :
/**
* Add slider_news section
*
*@since Magazine Palace 1.0.0
*/
function magazine_palace_add_slider_news_section() {
    $options = magazine_palace_get_theme_options();
    // Check if slider_news is enabled on frontpage
    $slider_news_enable = apply_filters( 'magazine_palace_section_status', true, 'slider_news_section_enable' );

    if ( true !== $slider_news_enable ) {
        return false;
    }
    // Get slider_news section details
    $section_details = array();
    $section_details = apply_filters( 'magazine_palace_filter_slider_news_section_details', $section_details );

    if ( empty( $section_details ) ) {
        return;
    }

// Render slider_news section now.
    magazine_palace_render_slider_news_section( $section_details );
}
endif;

if ( ! function_exists( 'magazine_palace_get_slider_news_section_details' ) ) :
/**
* slider_news section details.
*
* @since Magazine Palace 1.0.0
* @param array $input slider_news section details.
*/
function magazine_palace_get_slider_news_section_details( $input ) {
    $options = magazine_palace_get_theme_options();

    $content = array();

    $post_ids = array();

    for ( $i = 1; $i <= 3; $i++ ) {
        if ( ! empty( $options['slider_news_content_post_' . $i] ) )
            $post_ids[] = $options['slider_news_content_post_' . $i];
    }

    $args = array(
        'post_type'         => 'post',
        'post__in'          => ( array ) $post_ids,
        'posts_per_page'    => 3,
        'orderby'           => 'post__in',
        'ignore_sticky_posts'   => true,
        );                    
      
    // Run The Loop.
    $query = new WP_Query( $args );
    if ( $query->have_posts() ) : 
        while ( $query->have_posts() ) : $query->the_post();
    $page_post['id']        = get_the_id();
    $page_post['title']     = get_the_title();
    $page_post['auth_id']   = get_the_author_meta('ID');
    $page_post['url']       = get_the_permalink();
    $page_post['excerpt']   = get_the_content();
    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

    // Push to the main array.
    array_push( $content, $page_post );
    endwhile;
    endif;
    wp_reset_postdata();

    if ( ! empty( $content ) ) {
        $input = $content;
    }
    return $input;
}
endif;
// slider_news section content details.
add_filter( 'magazine_palace_filter_slider_news_section_details', 'magazine_palace_get_slider_news_section_details' );


if ( ! function_exists( 'magazine_palace_render_slider_news_section' ) ) :
/**
* Start slider_news section
*
* @return string slider_news content
* @since Magazine Palace 1.0.0
*
*/
function magazine_palace_render_slider_news_section( $content_details = array() ) {
    $options = magazine_palace_get_theme_options();
  ?>
<div id="content-wrapper" class="wrapper">

    <?php if(is_active_sidebar('slider-left-sidebar')): ?>
      <aside id="secondary" class="widget-area">
        <?php dynamic_sidebar( 'slider-left-sidebar' ); ?>
      </aside><!-- #secondary -->
    <?php endif; ?>
    <div id="primary" class="content-area">
        <div id="magazine_palace_slider_news_section" class="relative primary-post slider-news">
            <?php if ( is_customize_preview()):
                magazine_palace_section_tooltip( 'slider-news-class' );
            endif; ?>
            <?php if ( ! empty( $options['slider_news_title'] ) ) : ?>
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['slider_news_title'] ); ?></h2>
                </div><!-- .section-header -->
            <?php endif; ?>
            <div class="magazine_palace_slider_news_section-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": <?php echo esc_attr( $options['slider_news_autoplay_enable'] ) ?>, "draggable": true, "fade": false }'>
                <?php foreach ( $content_details as $content ) : ?>
                    <article>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <div class="overlay"></div>
                        </div>
                       
                        <div class="entry-container">
                            <span class="cat-links">
                                <?php the_category( '', '', $content['id'] ); ?>
                            </span>
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>
                            <div class="entry-meta">
                                <?php magazine_palace_posted_on( $content['id'] ); ?>
                                <span class="min-read"><?php echo magazine_palace_time_interval($content['excerpt']); echo esc_html__(' min to read', 'magazine-palace'); ?></span>
                            </div>
                        </div>
                    </article>
                <?php endforeach; ?>            
            </div>
        </div><!-- #magazine_palace_slider_news_section-aection -->
    </div>

    <?php if(is_active_sidebar('slider-news-right-sidebar')): ?>
      <aside id="secondary" class="widget-area">
        <?php dynamic_sidebar( 'slider-news-right-sidebar' ); ?>
      </aside><!-- #secondary -->
    <?php endif; ?>
</div>
<?php }
    endif;
